import type { Phone, AuthState } from '@gnuhost/gnuhost-vue3-core/models';
import { Store } from 'pinia';
export type Portal = {
    hrefs: {
        p: string;
        s: string;
        d: string;
    };
    icon: string;
    label: string;
};
export type AuthStoreType = Store<'auth', AuthState, {}, {
    getLoginUrl(redirectPath?: string): string;
    register(model: RegisterationFormModel, returnUrl?: string): Promise<void>;
    login(model: LoginFormModel, returnUrl?: string): Promise<boolean>;
    logout(): Promise<void>;
}>;
export type RegisterationFormModel = {
    email: string;
    password: string;
    first_name: string;
    last_name: string;
    street: string;
    city: string;
    state: string;
    zip_code: string;
    country: string;
    phone_number: string;
    street2: string | undefined | null;
    company_name: string | undefined | null;
    vat_number: string | undefined | null;
    website: string | undefined | null;
    _phone: Phone;
    _confirm_password: string;
};
export type LoginFormModel = {
    email: string;
    pass: string;
};
export type ServerDiskType = {
    type: string;
    name: string;
    tag: string;
};
export type VmsModelMapping = {
    provider: string;
    their_model: string;
    our_model: string;
    our_type: string;
    their_price: number;
};
export type VirtualMachineType = {
    type: string;
    name: string;
};
export type VirtualMachineModel = {
    offer_id: string;
    model: string;
    created_at: Date;
    type: string;
    m_label: string;
    ram: number;
    cpu_cores: number;
    disk_gb: number;
    cost: number;
    price: number;
    admin_notes: string;
};
export type ClientDiscount = {
    discount_id: string;
    client_id: string;
    created_at: Date;
    created_by: string;
    item_type: string;
    item_model: string;
    percent: number;
    original_price: number;
    new_price: number;
    start_dt: Date;
    end_dt: Date;
};
export type ClientProduct = {
    inventory_id: number;
    username: string;
    item_type_id: number;
    item_type: string;
    item_price: number;
    item_name: string;
    item_url: string;
    item_description: string;
    parent_id: number;
};
export type OfferTag = {
    offer_tag_id: number;
    name: string;
};
export type Offer = {
    offer_id: number;
    producer: string;
    label: string;
    cpu_model: string;
    cpu_count: number;
    cpu_cores: number;
    ram: number;
    disk_count: number;
    disk_gb: number;
    disk_type: string;
    disk_tag: string;
    location: Array<string>;
    description: string | undefined | null;
    price: number;
    tags: Array<string>;
};
export type OfferCreate = Omit<Offer, 'offer_id' | 'disk_tag'>;
export type OrderItem = {
    item_id: number;
    item_name: string;
    item_price: number;
    quantity: number;
    total: number;
};
export type OrderItemCreate = {
    p_order_id: string;
    p_offer_id: number;
    p_quantity: number;
};
export type OrderStatus = {
    Status: string;
};
export type Order = {
    order_id: string;
    created_at: Date;
    created_by: string;
    username: string;
    total: number;
    status: string;
    items: Array<OrderItem>;
    _selected_items: Array<OrderItem>;
};
export declare const OrderExportColumns: string[];
export type OrderCreate = {
    p_order_id: string | undefined | null;
    p_offer_id: number | undefined | null;
    p_item_name: string | undefined | null;
    p_item_price: number | undefined | null;
    p_quantity: number;
};
export type ClusterVM = {
    id: number;
    cluster: string;
    prox: number;
    vmid: number;
    client: string;
    name: string;
    port: number;
    state: string;
    ram: number;
    disk: number;
    ip: string;
    mac: string;
    cores: number;
    is_locked: boolean;
    type: string | undefined | null;
    model: string | undefined | null;
    notes: string | undefined | null;
    client_notes: string | undefined | null;
    url: string | undefined | null;
    _ram_gigabytes: number;
    _status_icon_class: string;
    _is_locked_icon_class: string;
};
export type ClientIp = {
    ip: string;
    comment: string;
};
export type ClientIpset = {
    client: string;
    comment: string;
    name: string;
    ipset: number;
    ipset_ips: Array<ClientIp>;
};
export type ClientIpsetUpsert = {
    p_ipset_name: string;
    p_comment: string;
    p_ips: Array<string>;
    p_client: string;
};
export type DedicatedServer = {
    created_at: Date;
    created_by: string;
    deleted_at: Date;
    client: string;
    hostname: string;
    tag: string;
    model: string;
    serial: string;
    offer_id: number;
    wan_ip: string;
    wan_mac: string;
    ipmi_hostname: string;
    ipmi_user: string;
    ipmi_pass: string;
    ipmi_license: string;
    ipmi_ip: string;
    ipmi_mac: string;
};
