import type { AxiosInstance } from 'axios';
import { type PagedEnumerable, type PaginationOptions, type KeyValuePair, type EnvironmentVariables } from '@gnuhost/gnuhost-vue3-core/models';
import type { AuthStoreType } from '../models';
export declare class ApiEndpoint {
    readonly partialUrl: string;
    readonly isPublic: boolean;
    readonly includeAuthHeader: boolean;
    selectColumns?: Array<string>;
    searchParams?: Array<string>;
    paginationOptions?: PaginationOptions;
    constructor(partial_url: string, is_public: boolean, include_auth_header: boolean);
    url(env: EnvironmentVariables): string;
}
export type PostPutPatchOptions = {
    returnType?: string;
    customHeaders?: Array<KeyValuePair>;
    allowedStatuses?: Array<number>;
};
export type ApiServiceOptions = EnvironmentVariables & {
    authStore: AuthStoreType;
    axiosInstance: AxiosInstance;
};
declare class ApiServiceClass {
    private static _instance;
    static get Instance(): ApiServiceClass;
    private readonly BOM;
    private constructor();
    private isUser;
    private initHeader;
    private sanitizePayload;
    private export;
    private options;
    configureApiServiceOptions(options: ApiServiceOptions): void;
    getPagedCollectionFromCacheOrDb<T>(endpoint: ApiEndpoint, payload?: any | null | undefined, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<Partial<T>>>;
    exportPagedCollectionFromCacheOrDb<T>(endpoint: ApiEndpoint, exportFileName: string, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<PagedEnumerable<Partial<T>>>;
    getPagedCollection<T>(endpoint: ApiEndpoint, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<Partial<T>>>;
    exportPagedCollection<T>(endpoint: ApiEndpoint, exportFileName: string, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<PagedEnumerable<Partial<T>>>;
    getPagedCollectionByPost<T>(endpoint: ApiEndpoint, payload?: any | null | undefined, accept?: string, customHeaders?: Array<KeyValuePair>, isExport?: boolean, exportFileName?: string): Promise<PagedEnumerable<Partial<T>>>;
    private _getCollectionResponse;
    getCollection<T>(endpoint: ApiEndpoint, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<Partial<T>[]>;
    getCollectionByPost<T>(endpoint: ApiEndpoint, payload?: any, accept?: string, customHeaders?: Array<KeyValuePair>): Promise<Partial<T>[]>;
    getSingle<T>(endpoint: ApiEndpoint, customHeaders?: Array<KeyValuePair>): Promise<Partial<T> | null>;
    private _post_put_patch;
    post<T>(endpoint: ApiEndpoint, payload: T, options?: PostPutPatchOptions): Promise<import("axios").AxiosResponse<any, any>>;
    put<T>(endpoint: ApiEndpoint, payload: T, options?: PostPutPatchOptions): Promise<import("axios").AxiosResponse<any, any>>;
    patch<T>(endpoint: ApiEndpoint, payload: T, options?: PostPutPatchOptions): Promise<import("axios").AxiosResponse<any, any>>;
    delete(endpoint: ApiEndpoint, customHeaders?: Array<KeyValuePair>): Promise<number>;
}
export declare const ApiService: ApiServiceClass;
export {};
